@@ -7,7 +7,7 @@ use Carp 'croak','carp';
 eval 'use Net::Netmask';
 eval 'use Net::ISP::Balance::ConfigData';
 
-our $VERSION    = '1.17';
+our $VERSION    = '1.18';
 
 =head1 NAME
 
@@ -1322,7 +1322,6 @@ sub lsm_config_text {
 	$result .= "connection {\n";
 	$result .= " name=$svc\n";
 	$result .= " device=$device\n";
-	$result .= " sourceip=$src_ip\n";
 	$result .= " checkip=$ping\n";
 	$result .= "}\n\n";
     }
@@ -1941,8 +1940,15 @@ sub sanity_fw_rules {
    }
 
     # allow appropriate outgoing traffic via the ISPs
-    for my $svc ($self->isp_services) {
-	my $ispdev = $self->dev($svc);
+    # NOTE: we use svc_config here so that we allow outgoing traffic
+    # on interfaces that might be down
+#    for my $svc ($self->isp_services) {
+#	my $ispdev = $self->dev($svc);
+#	$self->iptables("-A OUTPUT -o $ispdev -j ACCEPT");
+#    }
+    for my $svc (keys %{$self->{svc_config}}) {
+	next unless  $self->{svc_config}{$svc}{role} eq 'isp';
+	my $ispdev = $self->{svc_config}{$svc}{dev};
 	$self->iptables("-A OUTPUT -o $ispdev -j ACCEPT");
     }
 
